==> bloonix-core-1.36.tar.gz: bloonix-core-1.36/tests/test_runcmd.py <==
#!/usr/bin/python3

import bloonix.json as json
import os
import re
import sys
import unittest
from bloonix.exception import BloonixError
from bloonix.runcmd import RunCmd

class TestRunCmd(unittest.TestCase):
    def setUp(self):
        if os.path.isfile("tests/scripts/runcmd.py"):
            self.runcmd = "tests/scripts/runcmd.py"
        elif os.path.isfile("scripts/runcmd.py"):
            self.runcmd = "scripts/runcmd.py"

    def test_stdout(self):
        p = RunCmd(command=[self.runcmd, "echo=test"])
        self.assertTrue(p.stdout == "test")
        self.assertTrue(p.stderr == "")
        self.assertTrue(p.error is None)
        self.assertTrue(p.has_max_bytes_exceeded is False)
        self.assertTrue(p.has_os_error is False)
        self.assertTrue(p.has_unknown_error is False)
        self.assertTrue(p.has_timed_out is False)
        self.assertTrue(p.has_failed is False)

    def _test_stderr(self):
        p = RunCmd(command=[self.runcmd, "echo_to_stderr=test"])
        self.assertTrue(p.stdout == "")
        self.assertTrue(p.stderr == "test")
        self.assertTrue(p.error is None)
        self.assertTrue(p.has_max_bytes_exceeded is False)
        self.assertTrue(p.has_os_error is False)
        self.assertTrue(p.has_unknown_error is False)
        self.assertTrue(p.has_timed_out is False)
        self.assertTrue(p.has_failed is False)

    def _test_stdout_and_stderr(self):
        p = RunCmd(command=[self.runcmd, "echo=test1", "echo_to_stderr=test2"])
        self.assertTrue(p.stdout == "test1")
        self.assertTrue(p.stderr == "test2")
        self.assertTrue(p.error is None)
        self.assertTrue(p.has_max_bytes_exceeded is False)
        self.assertTrue(p.has_os_error is False)
        self.assertTrue(p.has_unknown_error is False)
        self.assertTrue(p.has_timed_out is False)
        self.assertTrue(p.has_failed is False)

    def _test_to_stdin(self):
        p = RunCmd(
            command=[self.runcmd, "stdin", "stdout"],
            to_stdin="written to stdin")
        data = json.loads(p.stdout)
        self.assertTrue(data["stdin"] == "written to stdin")
        self.assertTrue(p.error is None)
        self.assertTrue(p.has_max_bytes_exceeded is False)
        self.assertTrue(p.has_os_error is False)
        self.assertTrue(p.has_unknown_error is False)
        self.assertTrue(p.has_timed_out is False)
        self.assertTrue(p.has_failed is False)

    def _test_max_bytes(self):
        p = RunCmd(
            command=[self.runcmd, "echo=abcde"],
            bufsize=3,
            max_bytes=3)
        self.assertTrue(len(p.stdout) <= 3)
        self.assertTrue(re.search("command output exceeds max bytes", p.error))
        self.assertTrue(p.has_max_bytes_exceeded is True)
        self.assertTrue(p.has_os_error is False)
        self.assertTrue(p.has_unknown_error is False)
        self.assertTrue(p.has_timed_out is False)
        self.assertTrue(p.has_failed is True)

    def _test_failed(self):
        p = RunCmd(command="tests/this_script_does_not_exist")
        self.assertTrue(p.error)
        self.assertTrue(re.search("this_script_does_not_exist", p.error))
        self.assertTrue(p.has_max_bytes_exceeded is False)
        self.assertTrue(p.has_os_error is True)
        self.assertTrue(p.has_unknown_error is False)
        self.assertTrue(p.has_timed_out is False)
        self.assertTrue(p.has_failed is True)

    def _test_timeout(self):
        p = RunCmd(
            command=[self.runcmd, "sleep=10"],
            timeout=1)
        self.assertTrue(re.search("command timed out after 1 seconds", p.error))
        self.assertTrue(p.has_max_bytes_exceeded is False)
        self.assertTrue(p.has_os_error is False)
        self.assertTrue(p.has_unknown_error is False)
        self.assertTrue(p.has_timed_out is True)
        self.assertTrue(p.has_failed is True)

    def _test_exitcode(self):
        p = RunCmd(
            command=[self.runcmd, "exit=99"])
        self.assertTrue(p.exitcode == 99)

    def _test_pid(self):
        p = RunCmd(
            command=[self.runcmd, "stdout"])
        data = json.loads(p.stdout)
        self.assertTrue(p.pid == data["pid"])

    def _test_runtime(self):
        p = RunCmd(
            command=[self.runcmd, "sleep=1"])
        self.assertTrue(p.runtime >= 1)


unittest.main(verbosity=2)

==> bloonix-core-1.45.tar.gz: bloonix-core-1.45/tests/test_runcmd.py <==
#!/usr/bin/python3

import bloonix.json as json
import os
import re
import sys
import unittest
from bloonix.exception import BloonixError
from bloonix.runcmd import RunCmd

class TestRunCmd(unittest.TestCase):
    def setUp(self):
        if os.path.isfile("etc/scripts/runcmd.py"):
            self.runcmd = "etc/scripts/runcmd.py"
        elif os.path.isfile("scripts/runcmd.py"):
            self.runcmd = "scripts/runcmd.py"

    def test_stdout(self):
        p = RunCmd(command=[self.runcmd, "echo=test"])
        self.assertTrue(p.stdout == "test")
        self.assertTrue(p.stderr == "")
        self.assertTrue(p.error is None)
        self.assertTrue(p.has_max_bytes_exceeded is False)
        self.assertTrue(p.has_os_error is False)
        self.assertTrue(p.has_unknown_error is False)
        self.assertTrue(p.has_timed_out is False)
        self.assertTrue(p.has_failed is False)

    def _test_stderr(self):
        p = RunCmd(command=[self.runcmd, "echo_to_stderr=test"])
        self.assertTrue(p.stdout == "")
        self.assertTrue(p.stderr == "test")
        self.assertTrue(p.error is None)
        self.assertTrue(p.has_max_bytes_exceeded is False)
        self.assertTrue(p.has_os_error is False)
        self.assertTrue(p.has_unknown_error is False)
        self.assertTrue(p.has_timed_out is False)
        self.assertTrue(p.has_failed is False)

    def _test_stdout_and_stderr(self):
        p = RunCmd(command=[self.runcmd, "echo=test1", "echo_to_stderr=test2"])
        self.assertTrue(p.stdout == "test1")
        self.assertTrue(p.stderr == "test2")
        self.assertTrue(p.error is None)
        self.assertTrue(p.has_max_bytes_exceeded is False)
        self.assertTrue(p.has_os_error is False)
        self.assertTrue(p.has_unknown_error is False)
        self.assertTrue(p.has_timed_out is False)
        self.assertTrue(p.has_failed is False)

    def _test_to_stdin(self):
        p = RunCmd(
            command=[self.runcmd, "stdin", "stdout"],
            to_stdin="written to stdin")
        data = json.loads(p.stdout)
        self.assertTrue(data["stdin"] == "written to stdin")
        self.assertTrue(p.error is None)
        self.assertTrue(p.has_max_bytes_exceeded is False)
        self.assertTrue(p.has_os_error is False)
        self.assertTrue(p.has_unknown_error is False)
        self.assertTrue(p.has_timed_out is False)
        self.assertTrue(p.has_failed is False)

    def _test_max_bytes(self):
        p = RunCmd(
            command=[self.runcmd, "echo=abcde"],
            bufsize=3,
            max_bytes=3)
        self.assertTrue(len(p.stdout) <= 3)
        self.assertTrue(re.search("command output exceeds max bytes", p.error))
        self.assertTrue(p.has_max_bytes_exceeded is True)
        self.assertTrue(p.has_os_error is False)
        self.assertTrue(p.has_unknown_error is False)
        self.assertTrue(p.has_timed_out is False)
        self.assertTrue(p.has_failed is True)

    def _test_failed(self):
        p = RunCmd(command="tests/this_script_does_not_exist")
        self.assertTrue(p.error)
        self.assertTrue(re.search("this_script_does_not_exist", p.error))
        self.assertTrue(p.has_max_bytes_exceeded is False)
        self.assertTrue(p.has_os_error is True)
        self.assertTrue(p.has_unknown_error is False)
        self.assertTrue(p.has_timed_out is False)
        self.assertTrue(p.has_failed is True)

    def _test_timeout(self):
        p = RunCmd(
            command=[self.runcmd, "sleep=10"],
            timeout=1)
        self.assertTrue(re.search("command timed out after 1 seconds", p.error))
        self.assertTrue(p.has_max_bytes_exceeded is False)
        self.assertTrue(p.has_os_error is False)
        self.assertTrue(p.has_unknown_error is False)
        self.assertTrue(p.has_timed_out is True)
        self.assertTrue(p.has_failed is True)

    def _test_exitcode(self):
        p = RunCmd(
            command=[self.runcmd, "exit=99"])
        self.assertTrue(p.exitcode == 99)

    def _test_pid(self):
        p = RunCmd(
            command=[self.runcmd, "stdout"])
        data = json.loads(p.stdout)
        self.assertTrue(p.pid == data["pid"])

    def _test_runtime(self):
        p = RunCmd(
            command=[self.runcmd, "sleep=1"])
        self.assertTrue(p.runtime >= 1)


unittest.main(verbosity=2)
